@@ -9,7 +9,12 @@
 #![warn(missing_docs)]
 #![warn(missing_doc_code_examples)]
 
-pub mod ouroboros;
+pub mod network;
 
 pub mod ledger;
+
+#[doc(inline)]
 pub use pallas_crypto as crypto;
+
+#[doc(inline)]
+pub use pallas_codec as codec;
